==> org-lsst-ccs-subsystem-comcamvacuum-buses-1.0.21-sources.jar: org/lsst/ccs/subsystem/comcamvacuum/alerts/ComCamVacuumAlerts.java <==
package org.lsst.ccs.subsystem.comcamvacuum.alerts;

import org.lsst.ccs.bus.data.Alert;

/**
 * ComCam Alerts.
 * 
 * @author The LSST CCS Team
 */
public enum ComCamVacuumAlerts {


    // PLC Alerts

    VACUUM_PLC_NOT_ALIVE("VacuumPLCNotAlive", "Vacuum PLC not alive"),
    CRYO_VACUUM_BAD("CryoVacuumBad", "Cryo Vacuum Bad"),
    CRYO_GATE_FORCED_SHUT("CryoGateForcedShut", "Cryo Gate Valve Forced Shut"),
    CRYO_GATE_CANNOT_OPEN("CryoGateCannotOpen", "Cryo Gate Valve Cannot Open"),
    CRYO_TURBO_PUMP_BAD("CryoTurboPumpBad", "Cryo Turbo Pump Bad"),
    HX_VACUUM_BAD("HxVacuumBad", "HX Vacuum Bad"),
    HX_GATE_FORCED_SHUT("HxGateForcedShut", "HX Gate Valve Forced Shut"),
    HX_GATE_CANNOT_OPEN("HxGateCannotOpen", "HX Gate Valve Cannot Open"),
    HX_TURBO_PUMP_BAD("HxTurboPumpBad", "HX Turbo Pump Bad"),
    CRYO_TURBO_PUMP_STOPPED("CryoTurboPumpStopped", "Cryo Turbo Pump Stopped by CCS"),
    CRYO_ION_PUMPS_STOPPED("CryoIonPumpsStopped", "Cryo Ion Pumps Stopped by CCS"),
    CRYO_GATE_CLOSED("CryoGateClosed", "Cryo Gate Valve Closed by CCS"),


    // Monitoring Alerts

    /**
     * Alert raised when the cryo plate temperature is too high.
     */
    CRYO_PLATE_TEMPERATURE_TOO_HIGH("CryoPlateHighTemp","Alert for Cryo plate temperture too high"),
    /**
     * Alert raised when the cryo plate temperature is too low.
     */
    CRYO_PLATE_TEMPERATURE_TOO_LOW("CryoPlateLowTemp","Alert for Cryo plate temperture too low"),
    /**
     * Alert raised when the cold plate temperature is too high.
     */
    COLD_PLATE_TEMPERATURE_TOO_HIGH("ColdPlateHighTemp","Alert for Cold plate temperture too high"),
    /**
     * Alert raised when the cold plate temperature is too low.
     */
    COLD_PLATE_TEMPERATURE_TOO_LOW("ColdPlateLowTemp","Alert for Cold plate temperture too low"),

    /**
     * Alert raised when the cooler temperature is too low.
     */
    COOLER_TEMPERATURE_TOO_LOW("CoolerTempTooLow","Alert for cooler temperture too low"),
    /**
     * Alert raised when the cooler temperature is too high.
     */
    COOLER_TEMPERATURE_TOO_High("CoolerTempTooHigh","Alert for cooler temperture too high"),


    /**
     * Alert raised when the cooler power setting is too low.
     */
    COOLER_PWR_SETTING_TOO_LOW("CoolerPwrSettingTooLow","Alert for cooler power setting too low"),
    /**
     * Alert raised when the cooler power setting is too high.
     */
    COOLER_PWR_SETTING_TOO_High("CoolerPwrSettingTooHigh","Alert for cooler power setting too high"),


    /**
     * Alert raised when the cooler power is too high.
     */
    COOLER_PWR_TOO_HIGH("CoolerPwrTooHigh","Alert for cooler power too high"),


    /**
     * Alert raised when the cooler auto shutoff state is raised.
     */
    COOLER_AUTO_SHUTOFF("CoolerAutoShutOff","Alert for cooler auto shutoff raised"),


    /**
     * Alert raised when the cooler auto off temp is attempted to be set too high.
     */
    COOLER_AUTO_OFF_T_TOO_HIGH("CoolerAutoOffTooHigh","Alert for when the cooler auto off temp is attempted to be set too high"),


    /**
     * Alert raised when the cooler auto on temp is attempted to be set too high.
     */
    COOLER_AUTO_ON_T_TOO_HIGH("CoolerAutoOnTooHigh","Alert for when the cooler auto on temp is attempted to be set too high"),


    /**
     * Alert raised when the cooler reject temp is too high.
     */
    COOLER_REJECT_T_TOO_HIGH("CoolerRejectTTooHigh","Alert for when the cooler reject temperature is too high"),


    /**
     * Alert raised when the pressure is too low.
     */
    PRESSURE_TOO_LOW("PressureLow","Alert raised when the pressure too low"),
    /**
     * Alert raised when the pressure is too high.
     */
    PRESSURE_TOO_HIGH("PressureHigh","Alert raised when the pressure too high"),
    /**
     * Alert raised when the vacuum valve is shut off.
     */
    VACUUM_VALVE_SHUT_OFF("VacuumValveShutOff","Alert raised when the vacuum valve is shut off"),
    /**
     * Vacuum PLC is unresponsive
     */
    //    VACUUM_PLC_NOT_ALIVE("VacuumPLCNotAlive", "Vacuum PLC not alive"),
 
    /**
     * Alert raised when UPS goes onto battery.
     */
    UPS_ON_BATTERY("UPSOnBattery", "Alert raised when UPS goes onto battery"),
    /**
     * Alert raised when UPS becomes disconnected
     */
    UPS_DISCONNECTED("UPSDisconnected", "Alert raised when UPS becomes disconnected"),
    /**
     * Alert raised if TurboPump status shows pump failure
     */
    TURBO_PUMP_FAIL("TurboPumpFailure", "Alert raised when TurboPump status is Fail"),
    /**
     * Alert raised if TurboPump temperature is too high
     */
    TURBO_PUMP_OVERTEMP("TUrboPumpOverTemp","Alert raised when TurboPump temperature is too high"), 
    /**
     * Generic Alert.
     */
    GENERIC("GenericAlert","Generic Alert");
    
    
    private final String id, description;
    
    ComCamVacuumAlerts(String id, String description) {
        this.id = id;
        this.description = description;
    }
    
    public String getId() {
        return id;
    }

    public String getDescription() {
        return description;
    }
    
    public Alert getAlert() {
        return getAlert(null);
    }
    
    //Is this needed?
    private Alert getAlert(String prefix) {
        String aId = null;
        if ( prefix != null && ! prefix.isEmpty() ) {
            aId = prefix+"/"+id;
        } else {
            aId = id;
        }
        return new Alert(aId,description);
    }
    
}

==> org-lsst-ccs-subsystem-comcamvacuum-buses-1.0.26-sources.jar: org/lsst/ccs/subsystem/comcamvacuum/alerts/ComCamVacuumAlerts.java <==
package org.lsst.ccs.subsystem.comcamvacuum.alerts;

import org.lsst.ccs.bus.data.Alert;

/**
 * ComCam Alerts.
 * 
 * @author The LSST CCS Team
 */
public enum ComCamVacuumAlerts {


    // PLC Alerts

    VACUUM_PLC_NOT_ALIVE("VacuumPLCNotAlive", "Vacuum PLC not alive"),
    CRYO_VACUUM_BAD("CryoVacuumBad", "Cryo Vacuum Bad"),
    CRYO_GATE_FORCED_SHUT("CryoGateForcedShut", "Cryo Gate Valve Forced Shut"),
    CRYO_GATE_CANNOT_OPEN("CryoGateCannotOpen", "Cryo Gate Valve Cannot Open"),
    CRYO_TURBO_PUMP_BAD("CryoTurboPumpBad", "Cryo Turbo Pump Bad"),
    HX_VACUUM_BAD("HxVacuumBad", "HX Vacuum Bad"),
    HX_GATE_FORCED_SHUT("HxGateForcedShut", "HX Gate Valve Forced Shut"),
    HX_GATE_CANNOT_OPEN("HxGateCannotOpen", "HX Gate Valve Cannot Open"),
    HX_TURBO_PUMP_BAD("HxTurboPumpBad", "HX Turbo Pump Bad"),
    CRYO_TURBO_PUMP_STOPPED("CryoTurboPumpStopped", "Cryo Turbo Pump Stopped by CCS"),
    CRYO_ION_PUMPS_STOPPED("CryoIonPumpsStopped", "Cryo Ion Pump Stopped by CCS"),
    CRYO_GATE_CLOSED("CryoGateClosed", "Cryo Gate Valve Closed by CCS"),


    // Monitoring Alerts

    /**
     * Alert raised when the cryo plate temperature is too high.
     */
    CRYO_PLATE_TEMPERATURE_TOO_HIGH("CryoPlateHighTemp","Alert for Cryo plate temperture too high"),
    /**
     * Alert raised when the cryo plate temperature is too low.
     */
    CRYO_PLATE_TEMPERATURE_TOO_LOW("CryoPlateLowTemp","Alert for Cryo plate temperture too low"),
    /**
     * Alert raised when the cold plate temperature is too high.
     */
    COLD_PLATE_TEMPERATURE_TOO_HIGH("ColdPlateHighTemp","Alert for Cold plate temperture too high"),
    /**
     * Alert raised when the cold plate temperature is too low.
     */
    COLD_PLATE_TEMPERATURE_TOO_LOW("ColdPlateLowTemp","Alert for Cold plate temperture too low"),

    /**
     * Alert raised when the cooler temperature is too low.
     */
    COOLER_TEMPERATURE_TOO_LOW("CoolerTempTooLow","Alert for cooler temperture too low"),
    /**
     * Alert raised when the cooler temperature is too high.
     */
    COOLER_TEMPERATURE_TOO_High("CoolerTempTooHigh","Alert for cooler temperture too high"),


    /**
     * Alert raised when the cooler power setting is too low.
     */
    COOLER_PWR_SETTING_TOO_LOW("CoolerPwrSettingTooLow","Alert for cooler power setting too low"),
    /**
     * Alert raised when the cooler power setting is too high.
     */
    COOLER_PWR_SETTING_TOO_High("CoolerPwrSettingTooHigh","Alert for cooler power setting too high"),


    /**
     * Alert raised when the cooler power is too high.
     */
    COOLER_PWR_TOO_HIGH("CoolerPwrTooHigh","Alert for cooler power too high"),


    /**
     * Alert raised when the cooler auto shutoff state is raised.
     */
    COOLER_AUTO_SHUTOFF("CoolerAutoShutOff","Alert for cooler auto shutoff raised"),


    /**
     * Alert raised when the cooler auto off temp is attempted to be set too high.
     */
    COOLER_AUTO_OFF_T_TOO_HIGH("CoolerAutoOffTooHigh","Alert for when the cooler auto off temp is attempted to be set too high"),


    /**
     * Alert raised when the cooler auto on temp is attempted to be set too high.
     */
    COOLER_AUTO_ON_T_TOO_HIGH("CoolerAutoOnTooHigh","Alert for when the cooler auto on temp is attempted to be set too high"),


    /**
     * Alert raised when the cooler reject temp is too high.
     */
    COOLER_REJECT_T_TOO_HIGH("CoolerRejectTTooHigh","Alert for when the cooler reject temperature is too high"),


    /**
     * Alert raised when the pressure is too low.
     */
    PRESSURE_TOO_LOW("PressureLow","Alert raised when the pressure too low"),
    /**
     * Alert raised when the pressure is too high.
     */
    PRESSURE_TOO_HIGH("PressureHigh","Alert raised when the pressure too high"),
    /**
     * Alert raised when the vacuum valve is shut off.
     */
    VACUUM_VALVE_SHUT_OFF("VacuumValveShutOff","Alert raised when the vacuum valve is shut off"),
    /**
     * Vacuum PLC is unresponsive
     */
    //    VACUUM_PLC_NOT_ALIVE("VacuumPLCNotAlive", "Vacuum PLC not alive"),
 
    /**
     * Alert raised when UPS goes onto battery.
     */
    UPS_ON_BATTERY("UPSOnBattery", "Alert raised when UPS goes onto battery"),
    /**
     * Alert raised when UPS becomes disconnected
     */
    UPS_DISCONNECTED("UPSDisconnected", "Alert raised when UPS becomes disconnected"),
    /**
     * Alert raised if TurboPump status shows pump failure
     */
    TURBO_PUMP_FAIL("TurboPumpFailure", "Alert raised when TurboPump status is Fail"),
    /**
     * Alert raised if TurboPump temperature is too high
     */
    TURBO_PUMP_OVERTEMP("TUrboPumpOverTemp","Alert raised when TurboPump temperature is too high"), 
    /**
     * Generic Alert.
     */
    GENERIC("GenericAlert","Generic Alert");
    
    
    private final String id, description;
    
    ComCamVacuumAlerts(String id, String description) {
        this.id = id;
        this.description = description;
    }
    
    public String getId() {
        return id;
    }

    public String getDescription() {
        return description;
    }
    
    public Alert getAlert() {
        return getAlert(null);
    }
    
    //Is this needed?
    private Alert getAlert(String prefix) {
        String aId = null;
        if ( prefix != null && ! prefix.isEmpty() ) {
            aId = prefix+"/"+id;
        } else {
            aId = id;
        }
        return new Alert(aId,description);
    }
    
}
